#
# spec file for package libdnet
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           libdnet
Version:        1.17.0
Release:        1.1
Summary:        Library for Portable Interface to Low-Level Networking Routines
License:        BSD-3-Clause
URL:            https://github.com/dugsong/libdnet
Source0:        https://github.com/dugsong/libdnet/archive/%{name}-%{version}.tar.gz
# Skip the test subdir, as installing that is not necessary
Patch1:         skip-test-subdir.patch
BuildRequires:  check-devel
BuildRequires:  libbsd-devel
BuildRequires:  libtool

%description
libdnet provides a portable interface to several low-level
networking routines, including:
* network address manipulation
* kernel arp(4) cache and route(4) table lookup and manipulation
* network firewalling (IP filter, ipfw, ipchains, pf, PktFilter, ...)
* network interface lookup and manipulation
* IP tunnelling (BSD/Linux tun, Universal TUN/TAP device)
* raw IP packet and Ethernet frame transmission

%package -n libdnet1
Summary:        Library for Portable Interface to Low-Level Networking Routines

%description -n libdnet1
libdnet provides a portable interface to several low-level
networking routines, including:
* network address manipulation
* kernel arp(4) cache and route(4) table lookup and manipulation
* network firewalling (IP filter, ipfw, ipchains, pf, PktFilter, ...)
* network interface lookup and manipulation
* IP tunnelling (BSD/Linux tun, Universal TUN/TAP device)
* raw IP packet and Ethernet frame transmission

%package devel
Summary:        Development files for libdnet
Requires:       glibc-devel
Requires:       libdnet1 = %{version}

%description devel
libdnet provides a portable interface to several low-level
networking routines, including:
- network address manipulation
- kernel arp(4) cache and route(4) table lookup and manipulation
- network firewalling (IP filter, ipfw, ipchains, pf, PktFilter, ...)
- network interface lookup and manipulation
- IP tunnelling (BSD/Linux tun, Universal TUN/TAP device)
- raw IP packet and Ethernet frame transmission

%prep
%setup -q -n %{name}-%{name}-%{version}
%autopatch -p1

%build
ACLOCAL="aclocal -I config" autoreconf -fvi
%configure --disable-static
%make_build

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print

%post -n libdnet1 -p /sbin/ldconfig
%postun -n libdnet1 -p /sbin/ldconfig

%files -n libdnet1
%{_libdir}/libdnet.so.1*

%files devel
%license LICENSE
%doc README.md TODO THANKS
%{_bindir}/dnet-config
%{_includedir}/dnet.h
%dir %{_includedir}/dnet
%{_includedir}/dnet/*.h
%{_libdir}/libdnet.so
%{_mandir}/man?/dnet.*%{ext_man}

%changelog
* Thu Nov  9 2023 Dirk Müller <dmueller@suse.com>
- update to libdnet-1.17.0:
  * Stronger cmake support, updated autotools and a few smaller
    fixes.
- update to libdnet-1.16.4:
  * Various fixes around the build process (esp. cmake support +
    string.h include fixes)
  * Sync in latest changes
  * IPv6 support
  * Fixed some potential buffer overflows #41
  * configure: Use AC_CONFIG_HEADERS instead of deprecated
    AM_CONFIG_HEADER
  * Don't try to convert hostnames to addresses in addr_pton()
* Thu Apr 27 2023 Dirk Müller <dmueller@suse.com>
- update to 1.16.4:
  * Various fixes around the build process (esp. cmake support +
    string.h include fixes)
* Thu Jan 12 2023 Andrea Manzini <andrea.manzini@suse.com>
- update to 1.16.3:
  - IPv6 support
  - fixed some potential buffer overflows
* Thu Oct 15 2020 Dirk Mueller <dmueller@suse.com>
- update to 1.14:
  * many fixes included
- remove libdnet-autoreconf.patch
  libdnet-config-multilib.patch
  libdnet-fortify.patch
  reproducible.patch: drop (upstream)
- skip-test-subdir.patch: skip building tests, we don't need
  to install them and don't run them
* Wed Mar 18 2020 Tomáš Chvátal <tchvatal@suse.com>
- Drop python2 bindings as they don't make sense to be built with
  python2 removal
* Wed Aug  1 2018 bwiedemann@suse.com
- Add reproducible.patch to sort linked .o files
  to make package build reproducible (boo#1041090)
* Tue Jul 25 2017 jengelh@inai.de
- Fix RPM groups, trim summaries, drop pointless --with-pic.
* Mon Jul 17 2017 tchvatal@suse.com
- Switch to github
- Rename libdnet.patch to libdnet-autoreconf.patch
- Add patch to work properly on multilib systems:
  * libdnet-config-multilib.patch
- Install python bindings
- Add patch for fortify-sources error libdnet-fortify.patch
* Fri Mar 13 2015 tchvatal@suse.com
- Reorder bit with spec cleaner
- Make the descriptions bit smaller
* Sun Nov 13 2011 jengelh@medozas.de
- Remove redundant/unwanted tags/section (cf. specfile guidelines)
- Use %%_smp_mflags for parallel building
* Sun Nov 13 2011 coolo@suse.com
- add libtool as explicit buildrequire to avoid implicit dependency from prjconf
* Fri Dec  4 2009 dmueller@suse.de
- refresh patches
* Tue Oct 20 2009 crrodriguez@suse.de
- Update to version 1.12, various bugfixes including
  support for newwer python versions
- update download URLs
* Tue Oct  9 2007 crrodriguez@suse.de
- fix build by adapting to the library packaging policy
- remove useless libtool archive
- correct some minor packaging issues
* Thu Sep 21 2006 dmueller@suse.de
- Initial package (1.11)
